@@ -44,7 +44,9 @@ class Client:
             for record in json.loads(response.text)["payload"]:
                 unserialized.append(pickle.loads(bytes.fromhex(record["data"])))
 
-        return unserialized
+            return functools.reduce(operator.iconcat, unserialized, [])    
+        else:
+            return []
     
 def get_wheel_url(simulation_id):
         return f'{WHEEL_BASE_URL}/{simulation_id}/{WHEEL_NAME}'
\ No newline at end of file
